@@ -32,7 +32,9 @@ except ImportError as e:
 #
 
 
+HMAC_SECRET_HASH = hashlib.sha512
 HMAC_DIGEST      = hashlib.sha1
+HMAC_DIGEST_BITS = 160              # (160 = SHA1 digest size)
 HMAC_BLOCK_BITS  = 512              # (512=64*8 = SHA1 fixed block size)
 HMAC_KEY_BITS    = HMAC_BLOCK_BITS
 
